==> mozc_1.0.558.102.orig.tar.gz: mozc-1.0.558.102/unix/scim/imengine_factory.h <==
// Copyright 2010, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_
#define MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_

#define Uses_SCIM_FRONTEND_MODULE

#include <scim.h>

#include "base/base.h"  // for DISALLOW_COPY_AND_ASSIGN.

namespace mozc_unix_scim {

// This class implements IMEngineFactoryBase interface.
// See /usr/include/scim-1.0/scim_imengine.h for details of the interface.
class IMEngineFactory : public scim::IMEngineFactoryBase {
 public:
  explicit IMEngineFactory(const scim::ConfigPointer *config);
  virtual ~IMEngineFactory();

  // Overrides functions in scim::IMEngineFactoryBase.
  virtual scim::WideString get_name() const;
  virtual scim::String get_uuid() const;
  virtual scim::String get_icon_file() const;
  virtual scim::WideString get_authors() const;
  virtual scim::WideString get_credits() const;
  virtual scim::WideString get_help() const;
  virtual scim::IMEngineInstancePointer create_instance(
      const scim::String &encoding, int id = -1);

 private:
  const scim::ConfigPointer *config_;

  DISALLOW_COPY_AND_ASSIGN(IMEngineFactory);
};

}  // namespace mozc_unix_scim

#endif  // MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_

==> mozc_1.3.911.102.orig.tar.gz: mozc-1.3.911.102/unix/scim/imengine_factory.h <==
// Copyright 2010-2011, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_
#define MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_

#define Uses_SCIM_FRONTEND_MODULE

#include <scim.h>

#include "base/base.h"  // for DISALLOW_COPY_AND_ASSIGN.
#include "languages/japanese/lang_dep_spec.h"

namespace mozc_unix_scim {

// This class implements IMEngineFactoryBase interface.
// See /usr/include/scim-1.0/scim_imengine.h for details of the interface.
class IMEngineFactory : public scim::IMEngineFactoryBase {
 public:
  explicit IMEngineFactory(const scim::ConfigPointer *config);
  virtual ~IMEngineFactory();

  // Overrides functions in scim::IMEngineFactoryBase.
  virtual scim::WideString get_name() const;
  virtual scim::String get_uuid() const;
  virtual scim::String get_icon_file() const;
  virtual scim::WideString get_authors() const;
  virtual scim::WideString get_credits() const;
  virtual scim::WideString get_help() const;
  virtual scim::IMEngineInstancePointer create_instance(
      const scim::String &encoding, int id = -1);

 private:
  const scim::ConfigPointer *config_;
  mozc::japanese::LangDepSpecJapanese language_dependency_spec_japanese_;

  DISALLOW_COPY_AND_ASSIGN(IMEngineFactory);
};

}  // namespace mozc_unix_scim

#endif  // MOZC_UNIX_SCIM_IMENGINE_FACTORY_H_
